@@ -1,6 +1,6 @@
 from worker.event.event_handler import EventHandler
 from testcase.app.drilling_efficiency_app import DrillingEfficiency
-from worker.state.handlers.redis import RedisStateHandler
+from worker.state import RedisHandler
 
 redis_connection = None
 
@@ -14,7 +14,7 @@ def lambda_handler(event, context):
     """
 
     global redis_connection
-    redis_connection = RedisStateHandler.init(redis_connection)
+    redis_connection = RedisHandler.setup_existing_connection(redis_connection)
 
     app = DrillingEfficiency()
     event_handler = EventHandler(app)
