@@ -103,11 +103,9 @@ def point_main_envs(env: Literal['qa', 'staging', 'production', 'local']):
     # validating the environment
     Environment(env)
 
-    env_all_caps = env.upper()
-
-    api_url = os.getenv(f"API_ROOT_URL_{env}") or os.getenv(f"API_ROOT_URL_{env_all_caps}")
-    api_key = os.getenv(f"API_KEY_{env}") or os.getenv(f"API_KEY_{env_all_caps}")
-    cache_url = os.getenv(f"CACHE_URL_{env}") or os.getenv(f"CACHE_URL_{env_all_caps}")
+    api_url = os.getenv(f"API_ROOT_URL_{env}") or os.getenv("API_ROOT_URL")
+    api_key = os.getenv(f"API_KEY_{env}") or os.getenv("API_KEY")
+    cache_url = os.getenv(f"CACHE_URL_{env}") or os.getenv("CACHE_URL")
 
     if not all([api_url, api_key, cache_url]):
         raise ValueError("Missing environment variables!")
@@ -131,10 +129,8 @@ def setup_api_worker(env: Literal['qa', 'staging', 'production', 'local'], app_n
     # validating the environment
     Environment(env)
 
-    env_all_caps = env.upper()
-
-    api_url = os.getenv(f"API_ROOT_URL_{env}") or os.getenv(f"API_ROOT_URL_{env_all_caps}")
-    api_key = os.getenv(f"API_KEY_{env}") or os.getenv(f"API_KEY_{env_all_caps}")
+    api_url = os.getenv(f"API_ROOT_URL_{env}") or os.getenv("API_ROOT_URL")
+    api_key = os.getenv(f"API_KEY_{env}") or os.getenv("API_KEY")
 
     options = {
         "api_url": api_url,
@@ -155,7 +151,7 @@ def setup_redis_worker(env: Literal['qa', 'staging', 'production', 'local']):
     # validating the environment
     Environment(env)
 
-    cache_url = os.getenv(f"CACHE_URL_{env}") or os.getenv(f"CACHE_URL_{env.upper()}")
+    cache_url = os.getenv(f"CACHE_URL_{env}") or os.getenv("CACHE_URL")
 
     import redis
     redis_worker = redis.Redis.from_url(cache_url, decode_responses=True)
